Module: EAAL
- Defined in:
- lib/eaal/result.rb,
lib/eaal.rb,
lib/eaal/rowset.rb,
lib/eaal/cache/base.rb
Overview
– EAAL by Peter Petermann <[email protected]> This library is licensed under the terms found in the LICENSE file distributed with it ++
Defined Under Namespace
Modules: Cache, Exception, Result, Rowset
Classes: API
Constant Summary
collapse
- VERSION =
"0.1.12"
- @@version_string =
the version string, used as client name in http requests
"EAAL" + VERSION
- @@api_base =
the url used as basis for all requests, you might want to use gatecamper url or a personal proxy instead
"https://api.eveonline.com"
- @@additional_request_parameters =
hash, if :key => value pairs are added those will be added to each request
{}
- @@cache =
caching object, see EAAL::Cache::FileCache for an Example
EAAL::Cache::NoCache.new
Class Method Summary
collapse
Class Method Details
.additional_request_parameters ⇒ Object
56
57
58
|
# File 'lib/eaal.rb', line 56
def self.additional_request_parameters
@@additional_request_parameters
end
|
.additional_request_parameters=(val) ⇒ Object
59
60
61
|
# File 'lib/eaal.rb', line 59
def self.additional_request_parameters=(val)
@@additional_request_parameters = val
end
|
.api_base ⇒ Object
50
51
52
|
# File 'lib/eaal.rb', line 50
def self.api_base
@@api_base
end
|
.api_base=(val) ⇒ Object
53
54
55
|
# File 'lib/eaal.rb', line 53
def self.api_base=(val)
@@api_base = val
end
|
.cache ⇒ Object
62
63
64
|
# File 'lib/eaal.rb', line 62
def self.cache
@@cache
end
|
.cache=(val) ⇒ Object
65
66
67
|
# File 'lib/eaal.rb', line 65
def self.cache=(val)
@@cache = val
end
|
.version_string ⇒ Object
44
45
46
|
# File 'lib/eaal.rb', line 44
def self.version_string
@@version_string
end
|
.version_string=(val) ⇒ Object
47
48
49
|
# File 'lib/eaal.rb', line 47
def self.version_string=(val)
@@version_string = val
end
|